@@ -1,7 +1,7 @@
 package Perinci::Result::Format::Lite;
 
-our $DATE = '2018-01-31'; # DATE
-our $VERSION = '0.271'; # VERSION
+our $DATE = '2018-06-14'; # DATE
+our $VERSION = '0.272'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -133,16 +133,21 @@ sub __gen_table {
         }
     }
 
-    # add field units as label suffix to header (" (UNIT)")
+    # determine field labels
     {
         last unless $header_row && @$data;
         my $tff = $resmeta->{'table.fields'} or last;
-        my $tfu = $resmeta->{'table.field_units'} or last;
+        my $tfl = $resmeta->{'table.field_labels'};
+        my $tfu = $resmeta->{'table.field_units'};
         for my $i (0..$#columns) {
             my $field_idx = $field_idxs[$i];
             next unless $field_idx >= 0;
-            next unless defined $tfu->[$field_idx];
-            $data->[0][$i] .= " ($tfu->[$field_idx])";
+            if ($tfl && defined $tfl->[$field_idx]) {
+                $data->[0][$i] = $tfl->[$field_idx];
+            } elsif ($tfu && defined $tfu->[$field_idx]) {
+                # add field units as label suffix to header (" (UNIT)")
+                $data->[0][$i] .= " ($tfu->[$field_idx])";
+            }
         }
     }
 
@@ -519,7 +524,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.271 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2018-01-31.
+This document describes version 0.272 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2018-06-14.
 
 =head1 SYNOPSIS
 
